(function ($, Drupal) {
  Drupal.behaviors.WebformBooking = {
    attach: function (context, settings) {
      var formId = drupalSettings.webform_booking.formId;
      var $startDate = drupalSettings.webform_booking.startDate;
      var currentDate = new Date().toISOString().split('T')[0]; // '2024-02-21'
      var selectedDate = $startDate || currentDate;

      // Function to fetch and display days
      function fetchDays(date) {
        var formId = drupalSettings.webform_booking.formId;
        var daysUrl = '/get-days/' + formId + '/' + date;
        var $calendarContainer = $('#calendar-container', context);
        var currentDate = new Date(date);
        var currentYear = currentDate.getFullYear();
        var currentMonth = currentDate.getMonth();
        var $slotsContainer = $('#slots-container', context);
        $slotsContainer.off('click.WebformBookingDays');
        $.getJSON(daysUrl, function (daysData) {
          var monthSelect = createMonthSelect(date);
          $calendarContainer.empty();
          $calendarContainer.append(monthSelect); // Add month select at the top of the calendar

          // Generate week days header
          var weekDaysHtml = '<div class="week-days">';
          var weekDays = [Drupal.t('Mon'), Drupal.t('Tue'), Drupal.t('Wed'), Drupal.t('Thu'), Drupal.t('Fri'), Drupal.t('Sat'), Drupal.t('Sun')];
          weekDays.forEach(function (weekDay) {
            weekDaysHtml += `<div class="week-day">${weekDay}</div>`;
          });
          weekDaysHtml += '</div>';
          $calendarContainer.append(weekDaysHtml);

          // Determine the first day of the month
          var firstDay = new Date(currentYear, currentMonth, 1).getDay();
          var emptyDays = (firstDay === 0 ? 6 : firstDay - 1); // Adjust for Sunday being 0

          // Generate all days of the month with empty divs for alignment
          var daysInMonth = new Date(currentYear, currentMonth + 1, 0).getDate();
          var daysHtml = '<div class="calendar-days">';
          for (var i = 0; i < emptyDays; i++) {
            daysHtml += '<div class="calendar-day empty"></div>'; // Empty divs for alignment
          }
          for (var day = 1; day <= daysInMonth; day++) {
            var fullDate = `${currentYear}-${(currentMonth + 1).toString().padStart(2, '0')}-${day.toString().padStart(2, '0')}`;
            var dayClass = 'calendar-day';
            if (daysData.includes(fullDate)) {
              dayClass += ' available';
            }
            daysHtml += `<div class="${dayClass}" data-date="${fullDate}">${day}</div>`;
          }
          daysHtml += '</div>';
          $calendarContainer.append(daysHtml);
          $('.calendar-day.available', context).first().addClass('active');

          // Bind event handler to month select
          $('#month-select', context).once('WebformBooking').change(function () {
            var selectedMonth = $(this).val();
            resetSlots();
            fetchDays(`${currentYear}-${selectedMonth}-01`);
          });

          // Bind event handler to available days
          $('.calendar-day.available', context).once('WebformBooking').on('click.WebformBookingDays', function () {
            $('.calendar-day').removeClass('active');
            $(this).addClass('active');
            var selectedDate = $(this).data('date');
            resetSlots();
            fetchSlots(selectedDate);
          });
        });
      }

      // Function to create a select element for month navigation
      function createMonthSelect(selectedDate) {
        var date = new Date(selectedDate);
        var selectedMonth = date.getMonth();
        var monthSelect = '<select id="month-select">';
        for (var i = 0; i < 12; i++) {
          monthSelect += '<option value="' + (i + 1).toString().padStart(2, '0') + '"' +
            (i === selectedMonth ? ' selected' : '') + '>' +
            new Date(0, i).toLocaleString('default', { month: 'long' }) + '</option>';
        }
        monthSelect += '</select>';
        return monthSelect;
      }

      // Function to fetch and display time slots
      function fetchSlots(date) {
        var slotsUrl = '/get-slots/' + formId + '/' + date;
        var $slotsContainer = $('#slots-container', context);
        var $slotsContainer = $('#slots-container', context);
        $slotsContainer.off('click.WebformBookingSlot');

        $.getJSON(slotsUrl, function (slotsData) {
          $slotsContainer.empty(); // Clear previous slots

          $.each(slotsData, function (index, slot) {
            var $slot = $('<div>', {
              'class': 'calendar-slot ' + (slot.status === 'available' ? 'available' : 'unavailable'),
              'text': slot.time,
              'data-time': slot.time.split('-')[0] // Assuming "HH:MM-HH:MM"
            });

            // Append the slot to the container
            $slotsContainer.append($slot);

            // Only bind click events to available slots
            if (slot.status === 'available') {
              $slot.on('click.WebformBookingSlot', function () {
                $('.calendar-slot.available.selected', context).removeClass('selected');
                $(this).addClass('selected');
                selectSlot(date, $(this).data('time'));
              });
            }
          });
        });
      }

      // Set the value of the hidden field
      function selectSlot(date, time) {
        var dateTime = date + ' ' + time;
        $('#selected-slot').val(dateTime);
      }

      function resetSlots() {
        $('#selected-slot').val('');
        const slots = document.querySelectorAll('.calendar-slot');
        slots.forEach(slot => {
          slot.classList.remove('selected');
        });
      }

      // Initial fetch for the current month's days and today's slots
      fetchDays(selectedDate);
      fetchSlots(currentDate);

    }
  };
})(jQuery, Drupal);
